@@ -13,19 +13,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
-*/
+ */
+
+#include <string>
 
 #include <gtest/gtest.h>
+
 #include "sdf/sdf.hh"
 
 #include "test_config.h"
 
-const std::string SDF_TEST_FILE =
-  std::string(PROJECT_SOURCE_PATH) + "/test/integration/audio.sdf";
-
+//////////////////////////////////////////////////
 TEST(SDFParser, AudioSDF_FullParameters_noThrow)
 {
+  const auto sdfTestFile =
+    sdf::testing::TestFile("integration", "audio.sdf");
+
   sdf::SDFPtr p(new sdf::SDF());
   sdf::init(p);
-  ASSERT_TRUE(sdf::readFile(SDF_TEST_FILE, p));
+  ASSERT_TRUE(sdf::readFile(sdfTestFile, p));
 }
