@@ -13,52 +13,49 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
-*/
+ */
+
+#include <map>
+#include <string>
 
 #include <gtest/gtest.h>
-#include <map>
+
 #include "sdf/sdf.hh"
 
 #include "test_config.h"
 
-const std::string SDF_TEST_FILE = std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/fixed_joint_reduction.urdf";
-const std::string SDF_TEST_FILE_COLLISION =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/fixed_joint_reduction_collision.urdf";
-const std::string SDF_TEST_FILE_SIMPLE =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/fixed_joint_reduction_simple.urdf";
-const std::string SDF_TEST_FILE_VISUAL =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/fixed_joint_reduction_visual.urdf";
-const std::string SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/fixed_joint_reduction_collision_visual_extension.urdf";
-const std::string SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_SDF =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/fixed_joint_reduction_collision_visual_extension.sdf";
-const std::string SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/"
-  + "fixed_joint_reduction_collision_visual_empty_root.urdf";
-const std::string SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT_SDF =
-  std::string(PROJECT_SOURCE_PATH)
-  + "/test/integration/"
-  + "fixed_joint_reduction_collision_visual_empty_root.sdf";
+const char SDF_TEST_FILE[] = "fixed_joint_reduction.urdf";
+const char SDF_TEST_FILE_COLLISION[] = "fixed_joint_reduction_collision.urdf";
+const char SDF_TEST_FILE_SIMPLE[] = "fixed_joint_reduction_simple.urdf";
+const char SDF_TEST_FILE_VISUAL[] = "fixed_joint_reduction_visual.urdf";
+const char SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION[] =
+    "fixed_joint_reduction_collision_visual_extension.urdf";
+const char SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_SDF[] =
+    "fixed_joint_reduction_collision_visual_extension.sdf";
+const char SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT[] =
+    "fixed_joint_reduction_collision_visual_empty_root.urdf";
+const char SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT_SDF[] =
+    "fixed_joint_reduction_collision_visual_empty_root.sdf";
+const char SDF_TEST_FILE_PLUGIN_FRAME_EXTENSION[] =
+    "fixed_joint_reduction_plugin_frame_extension.urdf";
+
+static std::string GetFullTestFilePath(const char *_input)
+{
+  return sdf::testing::TestFile("integration", _input);
+}
 
 const double gc_tolerance = 1e-6;
 
 void FixedJointReductionEquivalence(const std::string &_file);
-void FixedJointReductionCollisionVisualExtension(
-  const std::string &_urdfFile, const std::string &_sdfFile);
+void FixedJointReductionCollisionVisualExtension(const std::string &_urdfFile,
+                                                 const std::string &_sdfFile);
 void FixedJointReductionCollisionVisualExtensionEmptyRoot(
   const std::string &_urdfFile, const std::string &_sdfFile);
 
 /////////////////////////////////////////////////
 TEST(SDFParser, FixedJointReductionEquivalenceTest)
 {
-  FixedJointReductionEquivalence(SDF_TEST_FILE);
+  FixedJointReductionEquivalence(GetFullTestFilePath(SDF_TEST_FILE));
 }
 
 /////////////////////////////////////////////////
@@ -67,7 +64,7 @@ TEST(SDFParser, FixedJointReductionEquivalenceTest)
 // version of urdfdom (see #63).
 TEST(SDFParser, FixedJointReductionVisualTest)
 {
-  FixedJointReductionEquivalence(SDF_TEST_FILE_VISUAL);
+  FixedJointReductionEquivalence(GetFullTestFilePath(SDF_TEST_FILE_VISUAL));
 }
 
 /////////////////////////////////////////////////
@@ -76,10 +73,9 @@ TEST(SDFParser, FixedJointReductionVisualTest)
 // FixedJointReductionVisualTest
 TEST(SDFParser, FixedJointReductionCollisionTest)
 {
-  FixedJointReductionEquivalence(SDF_TEST_FILE_COLLISION);
+  FixedJointReductionEquivalence(GetFullTestFilePath(SDF_TEST_FILE_COLLISION));
 }
 
-#if URDF_GE_0P3
 // this updated test will not work for old parser
 
 /////////////////////////////////////////////////
@@ -90,8 +86,8 @@ TEST(SDFParser, FixedJointReductionCollisionTest)
 TEST(SDFParser, FixedJointReductionCollisionVisualExtensionTest)
 {
   FixedJointReductionCollisionVisualExtension(
-    SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION,
-    SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_SDF);
+    GetFullTestFilePath(SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION),
+    GetFullTestFilePath(SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_SDF));
 }
 
 /////////////////////////////////////////////////
@@ -102,22 +98,21 @@ TEST(SDFParser, FixedJointReductionCollisionVisualExtensionTest)
 TEST(SDFParser, FixedJointReductionCollisionVisualExtensionEmptyRootTest)
 {
   FixedJointReductionCollisionVisualExtensionEmptyRoot(
-    SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT,
-    SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT_SDF);
+      GetFullTestFilePath(SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT),
+      GetFullTestFilePath(
+          SDF_TEST_FILE_COLLISION_VISUAL_EXTENSION_EMPTY_ROOT_SDF));
 }
-#endif
 
 /////////////////////////////////////////////////
-void FixedJointReductionCollisionVisualExtension(
-  const std::string &_urdfFile, const std::string &_sdfFile)
+void FixedJointReductionCollisionVisualExtension(const std::string &_urdfFile,
+                                                 const std::string &_sdfFile)
 {
   // load urdf file, load sdf file.
   // check to see that urdf load results are consistent with sdf load.
 
   // load urdf
-  sdf::SDFPtr urdfRobot(new sdf::SDF());
-  sdf::init(urdfRobot);
-  ASSERT_TRUE(sdf::readFile(_urdfFile, urdfRobot));
+  sdf::SDFPtr urdfRobot = sdf::readFile(_urdfFile);
+  ASSERT_TRUE(urdfRobot != sdf::SDFPtr());
 
   // load sdf
   sdf::SDFPtr sdfRobot(new sdf::SDF());
@@ -135,7 +130,9 @@ void FixedJointReductionCollisionVisualExtension(
   for (sdf::ElementPtr link = urdfModel->GetElement("link"); link;
        link = link->GetNextElement("link"))
   {
+    EXPECT_FALSE(link->HasElement("gravity"));
     EXPECT_FALSE(link->HasElement("self_collide"));
+    EXPECT_FALSE(link->HasElement("velocity_decay"));
     for (sdf::ElementPtr col = link->GetElement("collision"); col;
          col = col->GetNextElement("collision"))
     {
@@ -185,7 +182,9 @@ void FixedJointReductionCollisionVisualExtension(
   for (sdf::ElementPtr link = sdfModel->GetElement("link"); link;
        link = link->GetNextElement("link"))
   {
+    EXPECT_FALSE(link->HasElement("gravity"));
     EXPECT_FALSE(link->HasElement("self_collide"));
+    EXPECT_FALSE(link->HasElement("velocity_decay"));
     for (sdf::ElementPtr col = link->GetElement("collision"); col;
          col = col->GetNextElement("collision"))
     {
@@ -266,11 +265,12 @@ void FixedJointReductionCollisionVisualExtension(
             "file://media/materials/scripts/gazebo.material");
 
   EXPECT_EQ(urdf_child_link_1_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"), sdf::Color(0, 1, 0, 1));
+            Get<ignition::math::Color>("ambient"),
+            ignition::math::Color(0, 1, 0, 1));
   EXPECT_EQ(urdf_child_link_1_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"),
+            Get<ignition::math::Color>("ambient"),
              sdf_child_link_1_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"));
+            Get<ignition::math::Color>("ambient"));
 
   // child_link_1a
   //   <collision name='base_link_fixed_joint_lump__child_link_1a_collision_3'>
@@ -286,7 +286,7 @@ void FixedJointReductionCollisionVisualExtension(
   //    </material>
   EXPECT_EQ(urdf_child_link_1a_col->Get<int>("max_contacts"), 166);
   EXPECT_EQ(urdf_child_link_1a_col->Get<int>("max_contacts"),
-             sdf_child_link_1a_col->Get<int>("max_contacts"));
+            sdf_child_link_1a_col->Get<int>("max_contacts"));
 
   EXPECT_DOUBLE_EQ(urdf_child_link_1a_col->GetElement("surface")
     ->GetElement("friction")->GetElement("ode")->Get<double>("mu"), 0.6);
@@ -316,11 +316,12 @@ void FixedJointReductionCollisionVisualExtension(
 
   // ambient unassigned should be 0, 0, 0, 1
   EXPECT_EQ(urdf_child_link_1a_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"), sdf::Color(0, 0, 0, 1));
+            Get<ignition::math::Color>("ambient"),
+            ignition::math::Color(0, 0, 0, 1));
   EXPECT_EQ(urdf_child_link_1a_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"),
-             sdf_child_link_1a_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"));
+            Get<ignition::math::Color>("ambient"),
+            sdf_child_link_1a_vis->GetElement("material")->
+            Get<ignition::math::Color>("ambient"));
 
   // child_link_2
   //   <collision name='base_link_fixed_joint_lump__child_link_2_collision_2'>
@@ -332,7 +333,7 @@ void FixedJointReductionCollisionVisualExtension(
   // unassigne max_contacts defaut is 10
   EXPECT_EQ(urdf_child_link_2_col->Get<int>("max_contacts"), 10);
   EXPECT_EQ(urdf_child_link_2_col->Get<int>("max_contacts"),
-             sdf_child_link_2_col->Get<int>("max_contacts"));
+            sdf_child_link_2_col->Get<int>("max_contacts"));
 
   EXPECT_DOUBLE_EQ(urdf_child_link_2_col->GetElement("surface")
     ->GetElement("friction")->GetElement("ode")->Get<double>("mu"), 0.5);
@@ -353,7 +354,7 @@ void FixedJointReductionCollisionVisualExtension(
             "script_name_51");
   EXPECT_EQ(urdf_child_link_2_vis->GetElement("material")->
             GetElement("script")->Get<std::string>("name"),
-             sdf_child_link_2_vis->GetElement("material")->
+            sdf_child_link_2_vis->GetElement("material")->
             GetElement("script")->Get<std::string>("name"));
 
   EXPECT_EQ(urdf_child_link_2_vis->GetElement("material")->
@@ -362,11 +363,12 @@ void FixedJointReductionCollisionVisualExtension(
 
   // ambient unassigned should be 0, 0, 0, 1
   EXPECT_EQ(urdf_child_link_2_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"), sdf::Color(0, 0, 0, 1));
+            Get<ignition::math::Color>("ambient"),
+            ignition::math::Color(0, 0, 0, 1));
   EXPECT_EQ(urdf_child_link_2_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"),
-             sdf_child_link_2_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"));
+            Get<ignition::math::Color>("ambient"),
+            sdf_child_link_2_vis->GetElement("material")->
+            Get<ignition::math::Color>("ambient"));
 }
 
 /////////////////////////////////////////////////
@@ -459,7 +461,7 @@ void FixedJointReductionCollisionVisualExtensionEmptyRoot(
   //     <script><name>script_uri_71_name</name></script>
   EXPECT_EQ(urdf_child_link_1_col->Get<int>("max_contacts"), 177);
   EXPECT_EQ(urdf_child_link_1_col->Get<int>("max_contacts"),
-             sdf_child_link_1_col->Get<int>("max_contacts"));
+            sdf_child_link_1_col->Get<int>("max_contacts"));
 
   double urdf_mu1 = urdf_child_link_1_col->GetElement("surface")
     ->GetElement("friction")->GetElement("ode")->Get<double>("mu");
@@ -482,7 +484,7 @@ void FixedJointReductionCollisionVisualExtensionEmptyRoot(
             "script_uri_71_name");
   EXPECT_EQ(urdf_child_link_1_vis->GetElement("material")->
             GetElement("script")->Get<std::string>("name"),
-             sdf_child_link_1_vis->GetElement("material")->
+            sdf_child_link_1_vis->GetElement("material")->
             GetElement("script")->Get<std::string>("name"));
 
   EXPECT_EQ(urdf_child_link_1_vis->GetElement("material")->
@@ -490,11 +492,12 @@ void FixedJointReductionCollisionVisualExtensionEmptyRoot(
             "file://media/materials/scripts/gazebo.material");
 
   EXPECT_EQ(urdf_child_link_1_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"), sdf::Color(0, 1, 0, 1));
+            Get<ignition::math::Color>("ambient"),
+            ignition::math::Color(0, 1, 0, 1));
   EXPECT_EQ(urdf_child_link_1_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"),
-             sdf_child_link_1_vis->GetElement("material")->
-            Get<sdf::Color>("ambient"));
+            Get<ignition::math::Color>("ambient"),
+            sdf_child_link_1_vis->GetElement("material")->
+            Get<ignition::math::Color>("ambient"));
 }
 
 /////////////////////////////////////////////////
@@ -550,9 +553,9 @@ void FixedJointReductionEquivalence(const std::string &_file)
     linkPoses[linkName] = ignition::math::Pose3d(
       1.6, -2.72857, -0.342857, -2.14159, 0.141593, 0.858407);
     mapIxxIyyIzz[linkName] =
-      ignition::math::Vector3d(576.477, 527.681, 420.127);
+      ignition::math::Vector3d(576.477313, 527.680922, 420.127477);
     mapIxyIxzIyz[linkName] =
-      ignition::math::Vector3d(-65.6808, 134.562, 264.781);
+      ignition::math::Vector3d(-65.680839, 134.562430, 264.780538);
   }
 
   // Count collisions and visuals
@@ -614,17 +617,17 @@ void FixedJointReductionEquivalence(const std::string &_file)
     }
   }
 
-  if (_file.compare(SDF_TEST_FILE) == 0)
+  if (_file.compare(GetFullTestFilePath(SDF_TEST_FILE)) == 0)
   {
     EXPECT_EQ(countCollisions, 7u);
     EXPECT_EQ(countVisuals, 7u);
   }
-  else if (_file.compare(SDF_TEST_FILE_COLLISION) == 0)
+  else if (_file.compare(GetFullTestFilePath(SDF_TEST_FILE_COLLISION)) == 0)
   {
     EXPECT_EQ(countCollisions, 6u);
     EXPECT_EQ(countVisuals, 0u);
   }
-  else if (_file.compare(SDF_TEST_FILE_VISUAL) == 0)
+  else if (_file.compare(GetFullTestFilePath(SDF_TEST_FILE_VISUAL)) == 0)
   {
     EXPECT_EQ(countCollisions, 0u);
     EXPECT_EQ(countVisuals, 6u);
@@ -636,7 +639,7 @@ TEST(SDFParser, FixedJointReductionSimple)
 {
   sdf::SDFPtr robot(new sdf::SDF());
   sdf::init(robot);
-  ASSERT_TRUE(sdf::readFile(SDF_TEST_FILE_SIMPLE, robot));
+  ASSERT_TRUE(sdf::readFile(GetFullTestFilePath(SDF_TEST_FILE_SIMPLE), robot));
 
   std::map<std::string, double> linkMasses;
   std::map<std::string, ignition::math::Pose3d> linkPoses;
@@ -733,3 +736,31 @@ TEST(SDFParser, FixedJointReductionSimple)
     EXPECT_NEAR(iyz, mapIxyIxzIyz[linkName].Z(), gc_tolerance);
   }
 }
+
+/////////////////////////////////////////////////
+// This test uses a urdf that has chained fixed joints with plugin that
+// contains bodyName, xyzOffset and rpyOffset.
+// Test to make sure the offsets have the correct transfrom and frame of
+// reference
+TEST(SDFParser, FixedJointReductionPluginFrameExtensionTest)
+{
+  sdf::SDFPtr robot(new sdf::SDF());
+  sdf::init(robot);
+  ASSERT_TRUE(sdf::readFile(
+      GetFullTestFilePath(SDF_TEST_FILE_PLUGIN_FRAME_EXTENSION),
+      robot));
+
+  sdf::ElementPtr model = robot->Root()->GetElement("model");
+  sdf::ElementPtr plugin = model->GetElement("plugin");
+
+  auto xyzOffset = plugin->Get<ignition::math::Vector3d>("xyzOffset");
+  auto rpyOffset = plugin->Get<ignition::math::Vector3d>("rpyOffset");
+  auto bodyName = plugin->Get<std::string>("bodyName");
+  EXPECT_EQ("base_link", bodyName);
+  EXPECT_EQ(ignition::math::Vector3d(-0.707108, 1.70711, 0), xyzOffset);
+  EXPECT_EQ(ignition::math::Vector3d(0, 0, 1.5708), rpyOffset);
+
+  bool correctedOffset = plugin->Get<bool>("ignition::corrected_offsets");
+  EXPECT_TRUE(correctedOffset);
+}
+
